@@ -66,7 +66,7 @@ OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'kolla_config', 'global_config_settings',
                             'external_deploy_tasks', 'external_post_deploy_tasks',
                             'container_config_scripts', 'step_config',
-                            'monitoring_subscription',
+                            'monitoring_subscription', 'scale_tasks',
                             'external_update_tasks', 'external_upgrade_tasks']
 # ansible tasks cannot be an empty dict or ansible is unhappy
 ANSIBLE_TASKS_SECTIONS = ['upgrade_tasks', 'pre_upgrade_rolling_tasks',
@@ -134,9 +134,7 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                    'NovaApiLoggingSource': ['default'],
                                    'NovaComputeLoggingSource': ['default'],
                                    'NovaConductorLoggingSource': ['default'],
-                                   'NovaConsoleauthLoggingSource': ['default'],
                                    'NovaMetadataLoggingSource': ['default'],
-                                   'NovaPlacementLoggingSource': ['default'],
                                    'NovaSchedulerLoggingSource': ['default'],
                                    'NovaVncproxyLoggingSource': ['default'],
                                    'OctaviaApiLoggingSource': ['default'],
@@ -144,9 +142,9 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                    'OctaviaHousekeepingLoggingSource': ['default'],
                                    'OctaviaWorkerLoggingSource': ['default'],
                                    'OvnMetadataAgentLoggingSource': ['default'],
+                                   'PlacementLoggingSource': ['default'],
                                    'SaharaApiLoggingSource': ['default'],
                                    'SaharaEngineLoggingSource': ['default'],
-                                   'TripleoUILoggingSource': ['default'],
                                    # There's one template that defines this
                                    # differently, and I'm not sure if we can
                                    # safely change it.
@@ -213,7 +211,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
 PREFERRED_CAMEL_CASE = {
     'ec2api': 'Ec2Api',
     'haproxy': 'HAProxy',
-    'tripleo-ui': 'TripleoUI',
     'metrics-qdr': 'MetricsQdr'
 }
 
@@ -445,7 +442,7 @@ def validate_controller_no_ceph_role(filename, tpl):
                 return 1
     return 0
 
-def validate_with_compute_role_services(role_filename, role_tpl, exclude_service=()):
+def validate_with_compute_role_services(role_filename, role_tpl, exclude_service):
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     cmpt_tpl = yaml.load(open(cmpt_filename).read())
@@ -459,28 +456,9 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
               'ServicesDefault in roles/Compute.yaml'.format(role_filename,
               ', '.join(missing_services)))
         return 1
-
-    cmpt_us = cmpt_tpl[0].get('update_serial', None)
-    tpl_us = role_tpl[0].get('update_serial', None)
-
-    if 'OS::TripleO::Services::CephOSD' in role_services:
-        if tpl_us not in (None, 1):
-            print('ERROR: update_serial in {0} ({1}) '
-                  'is should be 1 as it includes CephOSD'.format(
-                      role_filename,
-                      tpl_us,
-                      cmpt_us))
-            return 1
-    elif cmpt_us is not None and tpl_us != cmpt_us:
-        print('ERROR: update_serial in {0} ({1}) '
-              'does not match roles/Compute.yaml {2}'.format(
-                  role_filename,
-                  tpl_us,
-                  cmpt_us))
-        return 1
-
     return 0
 
+
 def validate_multiarch_compute_roles(role_filename, role_tpl):
     errors = 0
     roles_dir = os.path.dirname(role_filename)
@@ -1091,15 +1069,13 @@ def validate(filename, param_map):
         if filename.startswith('./roles/'):
             retval = validate_role_name(filename)
 
-        if filename.startswith('./roles/ComputeHCI.yaml') or \
-                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
+        if filename.startswith('./roles/ComputeHCI.yaml'):
             retval |= validate_hci_computehci_role(filename, tpl)
 
         if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
                 filename.startswith('./roles/ComputeSriov.yaml') or \
                 filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
-                filename.startswith('./roles/ComputeSriovRT.yaml') or \
-                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
+                filename.startswith('./roles/ComputeSriovRT.yaml'):
             exclude = [
                 'OS::TripleO::Services::OVNController',
                 'OS::TripleO::Services::ComputeNeutronOvsAgent',
@@ -1127,10 +1103,6 @@ def validate(filename, param_map):
         if filename == './roles/Compute.yaml':
             retval |= validate_multiarch_compute_roles(filename, tpl)
 
-        if filename in ('./roles/ComputeLocalEphemeral.yaml',
-                        './roles/ComputeRBDEphemeral.yaml'):
-            retval |= validate_with_compute_role_services(filename, tpl)
-
         # NOTE(hjensas): The routed network data example is very different ...
         # We need to develop a more advanced validator, probably using a schema
         # definition instead.
